#
# spec file for package xdg-desktop-portal
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-desktop-portal
VCS: https://src.suse.de/SLFO-pool/xdg-desktop-portal#31164de7780d30daab8b6d080030b70fe64097311bea96dcfdb86d02defc478e
Version:        1.18.4
Release:        160000.1.13
Summary:        A portal frontend service for Flatpak
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/flatpak/xdg-desktop-portal
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  docutils
BuildRequires:  meson >= 0.58
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  xmlto
BuildRequires:  pkgconfig(flatpak)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.5.2
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.2.90
BuildRequires:  pkgconfig(libportal)
BuildRequires:  pkgconfig(libsystemd)
# Break cycle: we buildrequire flatpak, and flatpak has a requires on xdg-desktop-portal
#!BuildIgnore:  xdg-desktop-portal
# xdg-dfesktop-portal calls out to fusermount3 (in $PATH) (boo#1197567)
# document-portal/document-portal-fuse.c: char *umount_argv[] = { "fusermount3", "-u", "-z", (char *) path, NULL };
Requires:       %{_bindir}/fusermount3

%description
A portal frontend service for Flatpak and possibly other desktop containment frameworks.

xdg-desktop-portal works by exposing a series of D-Bus interfaces known as portals under
a well-known name (org.freedesktop.portal.Desktop) and object path (/org/freedesktop/portal/desktop).

The portal interfaces include APIs for file access, opening URIs, printing and others.

%package devel
Summary:        A portal frontend service for Flatpak -- Development files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
A portal frontend service for Flatpak and possibly other desktop containment frameworks.

xdg-desktop-portal works by exposing a series of D-Bus interfaces known as portals under
a well-known name (org.freedesktop.portal.Desktop) and object path (/org/freedesktop/portal/desktop).

This package contains convenience files for developers.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dpytest=disabled \
	%{nil}
%meson_build

%install
%meson_install

# own the packaging directories
install -d %{buildroot}%{_datadir}/xdg-desktop-portal/portals

%find_lang %{name} %{?no_lang_C}

%post
%systemd_user_post %{name}.service xdg-document-portal.service xdg-permission-store.service

%preun
%systemd_user_preun %{name}.service xdg-document-portal.service xdg-permission-store.service

%files
%license COPYING
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/interfaces
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/interfaces/*.xml
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.PermissionStore.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Desktop.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Documents.service
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/portals
%{_libexecdir}/%{name}
%{_libexecdir}/xdg-desktop-portal-validate-icon
%{_libexecdir}/xdg-document-portal
%{_libexecdir}/xdg-permission-store
%{_libexecdir}/xdg-desktop-portal-rewrite-launchers
%{_userunitdir}/%{name}.service
%{_userunitdir}/xdg-document-portal.service
%{_userunitdir}/xdg-permission-store.service
%{_userunitdir}/xdg-desktop-portal-rewrite-launchers.service
%{_mandir}/man5/portals.conf.5%{?ext_man}

%files devel
%license COPYING
%doc %{_datadir}/doc/%{name}/
%if %{pkg_vcmp meson < 0.62.0 }
%{_libdir}/pkgconfig/%{name}.pc
%else
%{_datadir}/pkgconfig/%{name}.pc
%endif

%files lang -f %{name}.lang
%license COPYING

%changelog
* Sat May 18 2024 andreas.stieger@gmx.de
- update to 1.18.4:
  + Don't allow commandline arrays when the first commandline item
    starts with whitespace or hyphen. (CVE-2024-32462, boo#1223110)
  + Do not store device access permission if it returned an error
  + Fix crash with config files without a default backend set
- includes changes from 1.18.3:
  + Don't try to read D-Bus object properties of Request objects on
    construction
  + Fix various memory and file descriptor leaks.
  + Minuscule optimization to the ScreenCast portal so that it
    stores restoration data with a single D-Bus call, instead of two.
  + Fix a crash in the OpenURI file when trying to open a non-
    existing file
  + Fix a bug in PipeWire that prevented cameras from being
    reported reliably.
  + Various smaller bug fixes.
* Fri Jan 12 2024 gmbr3@opensuse.org
- Also own the packaging directory used by portals themselves
* Fri Dec  1 2023 gmbr3@opensuse.org
- Own the directory which packages will use for portals.conf
  configuration files
* Thu Nov 23 2023 bjorn.lie@gmail.com
- Update to version 1.18.2:
  + Pass the token to the OpenURI portal and, when missing, an
    empty string.
  + Fix various memory and file descriptor leaks in the Document
    portal.
  + Make files and folders openend with the Document portal close
    properly. This should fix cases where the Document portal
    prevented external devices from unmounting, due to files inside
    them not getting closed after applications stop using them.
  + Implement FUSE getlk and setlk callbacks.This should enable
    using sqlite3 through the Document portal.
  + Properly resolve fd symlinks before opening them with
    O_NOFOLLOW.
  + Fix cases where the portal id is assumed to match the .desktop
    file name.
  + Allow sending directories in the file transfer portal. This
    should make it possible to, among other things, drag and drop
    folders and files simultaneously from and to sandboxed
    applications.
  + Fallback to a hardcoded check to xdg-desktop-portal-gtk in the
    absence of any other portal or configuration file, as a last
    resort mechanism.
  + Various smaller fixes to the build system.
* Thu Oct 26 2023 bjorn.lie@gmail.com
- Update to version 1.18.1:
  + Communicate better when the Background portal kills an app.
  + Properly quote Flatpak command in the Background portal.
  + Improve documentation of the "cursor_mode" propery of the
    ScreenCast backend D-Bus interface.
  + Fix ScreenCast portal removing transient restore permissions
    too early. This fixes screen sharing dialogs on Chromium asking
    for the screen multiple times.
  + Only send the Closed session signal to the sender.
  + Add Meson options to disable building with Bubblewrap, and
    without the Flatpak portal documentation. Disabling Bubblewrap
    is highly discouraged, and only meant to be used on platforms
    that do not currently support it. By disabling Bubblewrap,
    bitmap validation happens without a sandbox, which is highly
    insecure since image parsing is a common source of exploits.
    Really, just do not disable Bubblewrap please.
  + Improve the manpage of portals.conf.
  + Various spelling fixes to the Document portal.
  + Add a new website! We don't have a fancy domain yet, but the
    website can be accessed at
    https://flatpak.github.io/xdg-desktop-portal/
  + Improve pid mapping for host system apps. This should get rid
    of some rare, unnecessary warnings.
  + Adjust documentation of Global Shortcuts portal's timestamps to
    millisecond granularity.
  + Bump minimum Meson version to 0.58.
* Tue Oct  3 2023 alarrosa@suse.com
- Support building with meson 0.61.x used by SLE, where .pc files
  in dataonly packages are installed to %%_libdir unlike in
  meson >= 0.62.0 where the default was changed to %%_datadir.
* Mon Sep 18 2023 bjorn.lie@gmail.com
- Update to version 1.18.0:
  + Highlights:
  - A new config-based portal matching mechanism that gives
    preciser control over which portal backends are picked for
    each portal.
  - New portals: Clipboard and Input Capture.
  - The settings portal now documents an 'accent-color' key.
  + New portal APIs:
  - Introduce a new Clipboard portal. This portal extends the
    Remote Desktop portal by adding support for sharing clipboard
    between remote machines.
  - Introduce a new Input Capture portal. This portal adds
    mechanisms for taking control of input devices. The primary
    usage model is centered around the InputLeap and Synergy use
    cases, where local devices are used to control remote
    displays.
  - Add an "accept-label" option the the Print portal. This lets
    apps suggest a proper label to the print operation.
  - Document a new 'accent-color' key in the Settings portal.
    This key represents an arbitrary color in sRGB colorspace.
    How implementations of the portal provide this key is
    entirely dependent on their internal policies and design.
  - Support restoring remote desktop sessions.
  - Introduce the ReadOne() method in the Settings portal. This
    method is now preferred over the Read() method, as Read()
    mistakenly returned a variant inside a variant. The Read()
    method will continue to exist for compatibility with existing
    apps, but its usage is deprecated. We recommend apps to port
    to the ReadOne() method. Apps can decide whether to use
    ReadOne() or Read() by looking at the version of the Settings
    portal.
  + Changes that might be relevant for distributors:
  - Rework how portal implementations are loaded. This new, more
    robust system allows selecting specific backends for specific
    portals, and layering them when necessary. Platforms that
    provide portals implementation are encouraged to provide a
    suitable configuration file.
  - Drop the Autotools build. Meson is now the only supported
    build system.
  - The PipeWire dependency is now mandatory.
  - Bump GLib dependency to 2.66.
  + Misc changes:
  - Improve robustness of the OpenURI portal by validating more
    URIs.
  - Various small visual tweaks to the generated documentation.
  - Various fixes to the Global Shortcuts portal.
  - Stop using the deprecated GTimeVal struct.
  - Document xdg-desktop-portal versioning scheme.
  - Fix various issues in the OpenURI portal.
  - Bump interface version of the Printer portal to 2.
  - Validate addresses following the HTML specs in the Email
    portal.
  - Document minimum version of the new ReadOne() method of the
    Settings portal.
  - Add a mapping id property to the ScreenCast portal.
  - Add activation token parameter to the Email portal.
  - Test tarball generation in CI.
  - Updated translations.
- Add docutils BuildRequires: New dependency.
* Wed Aug  9 2023 bjorn.lie@gmail.com
- Update to version 1.17.0:
  + Drop the Autotools build. Meson is now the only supported build
    system.
  + Rework how portal implementations are loaded. This new, more
    robust system allows selecting specific backends for specific
    portals, and layering them when necessary. Platforms that
    provide portals implementation are encouraged to provide a
    suitable configuration file.
  + Introduce a new Clipboard portal. This portal extends the
    Remote Desktop portal by adding support for sharing clipboard
    between remote machines.
  + Introduce a new Input Capture portal. This portal adds
    mechanisms for taking control of input devices. The primary
    usage model is centered around the InputLeap and Synergy use
    cases, where local devices are used to control remote displays.
  + Stop using the deprecated GTimeVal struct
  + Bump GLib dependency to 2.66
  + Add an "accept-label" option the the Print portal. This lets
    apps suggest a proper label to the print operation.
  + Various fixes to the Global Shortcuts portal.
  + Support restoring remote desktop sessions.
  + Improve robustness of the OpenURI portal by validating more
    URIs.
  + The PipeWire dependency is now mandatory.
  + Various improvements for the test suite.
  + Updated translations.
- Drop 0001-portal-impl-Only-return-found-implementation-if-it-launched.patch
  fixed upstream.
- Switch to meson buildsystem following upstream changes. Add meson
  BuildRequires and macros.
* Fri Jun 23 2023 alarrosa@suse.com
- Add patch from upstream to avoid creating portals with
  non-functional backends . This was mentioned in bsc#1212037 and
  since I included this fix in the SP4 update that fixed the issue,
  I'm fixing this in Factory/SP5 too for consistentcy.
  * 0001-portal-impl-Only-return-found-implementation-if-it-launched.patch
* Tue Dec 13 2022 bjorn.lie@gmail.com
- Update to version 1.16.0:
  + Introduce a new background monitoring service. This allows
    desktop environments to list applications that are running in
    background, that is, sandboxed applications running without a
    visible window. Desktop environments can display these
    background running applications in their interfaces, and allow
    users to control their execution.
  + Introduce the Global Shortcuts portal. This portal allows
    applications to register and receive keyboard shortcuts even
    when they're not focused. This was a highly requested feature,
    especially on Wayland desktops. There are improvements to come,
    but portal backends can now implement this new portal.
  + Various CI improvements.
  + Updated translations.
* Fri Aug 12 2022 dimstar@opensuse.org
- Update to version 1.15.0:
  + Add Meson build files. For now, both Autotools and Meson are
    available in the source tree.
  + Make the Screenshot portal request permission to take
    screenshots. Frontends that implement the version 2 of
    org.freedesktop.portal.impl.Screenshot portal can now be aware
    that the screenshot permission was granted through the new
    'permission_store_checked' option, and skip any kind of dialog
    when that is the case.
  + Stop sending the app id quoted in the Background portal.
  + Fix a bug in cgroup name parsing.
  + Various fixes to the Realtime portal.
  + Updated translations.
* Thu Aug  4 2022 bjorn.lie@gmail.com
- Update to version 1.14.6:
  + realtime:
  - Remap thread ids.
  - Use correct types.
* Thu Jul 21 2022 bjorn.lie@gmail.com
- Update to version 1.14.5:
  + realtime: Fix realtime: fix priority type in
    MakeThreadHighPriority.
* Thu May  5 2022 andreas.stieger@gmx.de
- update to 1.14.4:
  + fix regression introduced in 1.14.0 which caused invalid
    autostart files to be generated
* Sat Apr 16 2022 andreas.stieger@gmx.de
- update to 1.14.3:
  + remote-desktop: Fix a memory corruption that was causing
    segfaults
* Thu Mar 31 2022 luc14n0@opensuse.org
- Update to version 1.14.2:
  + Fix a frequent crash with WebKit processes.
  + Fix a bug in parsing the app ID from the cgroup on KDE.
  + Documentation improvements.
  + Updated translations.
* Wed Mar 30 2022 dimstar@opensuse.org
- Update /usr/bin/fusermount requires to /usr/bin/fusermount3: the
  code has been changed to call fusermount3 as  part of version
  1.14.0: document-portal: Move to the libfuse3 API (boo#1197567).
* Sat Mar 19 2022 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + Fix an issue in 1.14.0 where xdg-desktop-portal.service
    starting before graphical-session-pre.target would cause the
    GNOME session to deadlock by moving code to a new libexec
    binary which handles deleting or migrating .desktop files (and
    icons) from the dynamic launcher portal for apps which have
    been uninstalled or renamed.
  + Fix some bugs in the aforementioned launcher migration
    implementation, "xdg-desktop-portal-rewrite-launchers".
  + Fix build without libsystemd.
* Fri Mar 18 2022 alarrosa@suse.com
- Update to version 1.14.0:
  + Add a new "dynamic launcher" portal, which can install .desktop
    files and accompanying icons after user confirmation.
  + Rework handling of empty app IDs: In case an empty string app
    ID is stored in the permission store, this permission is now
    shared only by apps whose app ID couldn't be determined, rather
    than all unsandboxed apps.
  + Use libsystemd (when available) to try to determine the app ID
    of unsandboxed processes. This is useful since some portals
    otherwise can't be used by host apps.
  + Make x-d-p start on session start, which is needed for the
    dynamic launcher portal to handle rewriting launchers for apps
    that have been renamed.
  + Bring back the copy of Flatpak's icon-validator, which was
    dropped many releases ago.
  + Icon validation is now required for the notification and
    dynamic launcher portals (previously it was only done if the
    "flatpak-validate-icon" binary could be found).
  + document-portal: Move to the libfuse3 API
  + document-portal: Use renameat2 sys call
  + document-portal: Use mutex to fix concurrency bug
  + realtime: Fix error code paths
  + realtime: Fix MakeThreadHighPriorityWithPID method
  + screencast: Fix an error when restoring streams
  + ci: Various improvements
  + Documentation improvements
  + Updated translations.
- Replace BuildRequires: pkgconfig(fuse) with pkgconfig(fuse3)
  since document-portal moved to use it.
- Add BuildRequires: pkgconfig(libsystemd) and
  pkgconfig(gdk-pixbuf-2.0) which are now used.
* Sat Mar  5 2022 bjorn.lie@gmail.com
- Pass --docdir=%%%%{_defaultdocdir}/%%%%{name}/ to configure, install
  docs in standard distro docs dir, and move to devel sub-package,
  as it is developer documentation.
* Mon Jan 17 2022 andreas.stieger@gmx.de
- update to version 1.12.1:
  + Fix a crash in the device portal
- includes changes from 1.12.0:
  + Place portals in the systemd session.slice
  + settings: Add color-scheme key
  + open-uri: Avoid a sync call to org.freedesktop.FileManager
  + screncast: Allow restoring previous sessions
  + Add a portal for requesting realtime permissions
  + ci: Many improvements
  + Publish the docs from a ci job
  + Translation updates
* Fri Oct  8 2021 bjorn.lie@gmail.com
- Update to version 1.10.1:
  + Revert a breaking change to the screencast and inhibit portal.
* Sat Sep 18 2021 bjorn.lie@gmail.com
- Update to version 1.10.0:
  + Remap /run/flatpak/app, for Flatpak 1.11.x
  + Remap /var/config and /var/data
  + permission-store: Avoid a crash
  + permissions-store: Add GetPermission
  + screencast: Add 'virtual' source type
  + openuri: Use real path for OpenDirectory
  + location: Fix accuracy levels
  + Add power profile monitor implementation
  + Updated translations.
* Thu May  6 2021 rpm@fthiessen.de
- Update to version 1.8.1:
  * openuri: Fix an fd leak
  * filechooser: Fix directory support
  * documents: Add snap support
  * wallpaper: Fix a crash
  * Translation updates
- Drop unneeded fontconfig BuildRequires
* Thu Jan 14 2021 fcrozat@suse.com
- Ensure systemd rpm macros are called at install/uninstall times
  for systemd user services.
- Add BuildRequires on systemd-rpm-macros.
* Thu Jan  7 2021 bjorn.lie@gmail.com
- Update to version 1.8.0:
  + openuri:
  - Allow skipping the chooser for more URL tyles
  - Robustness fixes
  + filechooser: Return the current filter
  + camera:
  - Make the client node visible
  - Don't leak pipewire proxy
  + Fix file descriptor leaks
  + Testsuite improvements
  + Updated translations.
- Changes from version 1.7.2:
  + document:
  - Reduce the use of open fds
  - Add more tests and fix issues they found
  + Fix the build with musl.
- Changes from version 1.7.1:
  + filechooser:
  - Add a "directory" option
  - Document the "writable" option
  + document: Expose directories with their proper name
- Changes from version 1.7.0:
  + testsuite improvements
  + background: Avoid a segfault
  + screencast: Require pipewire 0.3
  + document:
  - Support exporting directories
  - New fuse implementation
  + Better support for snap and toolbox
  + Updated translations.
- Drop patches fixed upstream:
  + xdg-dp-port-pipewire-3-api.patch
  + 0001-Fix-use-after-free-in-xdg_get_app_info_from_pid.patch
  + 0002-add-AssumedAppArmorLabel-key-to-D-Bus-service-files.patch
  + 0003-Fix-criticals-if-no-default-handler-for-desired-type.patch
* Fri Aug 28 2020 dfaggioli@suse.com
- Require /usr/bin/fusermount: xdg-document-portal calls out to the
  binary. Without it, files or dirs can be selected, but
  whatever is done with or in them, will not have any effect
  (boo#1175899).
* Tue Jul  7 2020 callumjfarmer13@gmail.com
- Fixes for %%_libexecdir changing to /usr/libexec
* Mon Apr  6 2020 alarrosa@suse.com
- Add patch from upstream to fix a use-after-free case:
  * 0001-Fix-use-after-free-in-xdg_get_app_info_from_pid.patch
- Add patch from upstream to add AssumedAppArmorLabel key to D-Bus
  service files to allow sandboxed processes to activate the portal
  services if the sandbox makes use of AppArmor D-Bus mediation
  rules that depend on the service's security label:
  * 0002-add-AssumedAppArmorLabel-key-to-D-Bus-service-files.patch
- Add patch from upstream to fix a null pointer usage when no
  default handler is set for desired type:
  * 0003-Fix-criticals-if-no-default-handler-for-desired-type.patch
* Fri Feb 21 2020 bjorn.lie@gmail.com
- Add xdg-dp-port-pipewire-3-api.patch: Port to use new
  pipewire-3.0 api. Following this, replace
  pkgconfig(libpipewire-2.0) with pkgconfig(libpipewire-3.0)
  BuildRequires. Also add libtool BuildRequires and pass autoreconf
  as the patch touches the buildsystem.
* Fri Jan 31 2020 alarrosa@suse.com
- Set encoding before building to fix a build error in SLE.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Fri Dec 20 2019 bjorn.lie@gmail.com
- Update to version 1.6.0:
  + tests: Adapt to libportal api changes.
- Changes from version 1.5.4:
  + background:
  - Add a signal to the impl api.
  - Rewrite the monitoring to better track when apps disappear.
  + permissions: Fix SetValue handling of GVariant wrapping. This
    is an api change.
  + openuri:
  - Add a per-type always-ask option.
  - Show the app chooser dialog less often.
  + memorymonitor: A new portal to let apps receive low memory
    warnings.
  + filetransfer: A new portal to rewrite file paths between
    sandboxes.
- Changes from version 1.5.3:
  + Add more tests.
  + location: Various fixes.
  + document portal: Monitor fuse mount.
  + openuri:
  - Only ask 3 times to use the same app.
  - Add an 'ask' option.
  + Fix build from git.
  + email: Allow multiple addresses, cc and bcc.
  + filechooser: Allow saving multiple files.
  + Update translations.
- Changes from version 1.5.2:
  + Add many more tests, using libportal.
  + gamemode: Add a pidfd-based api.
  + inhibit: Send a Response signal.
  + openuri: Add an OpenDirectory api.
  + Updated translations.
- Changes from version 1.5.1:
  + Add a portal for setting desktop backgrounds
  + Add tests.
  + Optionally use libportal (for tests).
- Changes from version 1.5.0:
  + Add a secret portal that is meant be used via libsecret inside
    the sandbox. One backend for this will live in gnome-keyring,
    others are possible.
  + Fix a file descriptor leak.
  + Reduce log spam.
  + Updated translations.
- Add pkgconfig(libportal) BuildRequires: New dependency.
* Thu Jun 13 2019 bjorn.lie@gmail.com
- Update to version 1.4.2:
  + Build fixes.
- Changes from version 1.4.1:
  + Build fixes.
- Changes from version 1.4.0:
  + Add a background & autostart portal.
  + Add a gamemode portal.
  + Add a camera portal.
  + Require pipewire 0.2.6.
  + inhibit: Track session state.
  + documents: Fix a ref-counting bug.
  + screencast:
  - Add cursor modes.
  - Memory leak fixes.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) BuildRequires: New dependency.
* Wed Apr 10 2019 dimstar@opensuse.org
- BuildIgnore xdg-desktop-portal: self-requires is not needed here
  to build. Flatkpak has a (correct) dependency on
  xdg-desktop-portal, but since we don't run flatpak during build,
  but merely require its -devel package, we can break up this
  chain.
* Wed Jan 30 2019 bjorn.lie@gmail.com
- Update to version 1.2.0:
  + notification:
  - Use icon validator from flatpak.
  - Don't leave temp files around.
  + email: Validate options better.
  + inhibit: Validate options better.
  + file chooser: Add support for setting the current filter.
  + Updated translations.
- Changes from version 1.1.1:
  + Validate icons in notifications.
  + Respect lockdown settings.
  + Write back permissions for notifications to indicate portal
    use.
  + Set st_nlink in the documents portal.
  + Add infrastructure for validating options.
  + Validate email addresses.
  + Updated translations.
- Changes from version 1.1.0:
  + Add a location portal, this requires geoclue 2.5.2.
  + Add a settings portal, for desktop-wide settings like XSettings
    or kdeglobals.
  + Allow locking down printing, save-to-disk and opening uris.
  + Monitor application changes in the open uri portal.
  + Add more tests.
  + Fix a crash when xdg-desktop-portal-gtk times out (boo#1118121,
    gh#flatpak/xdg-desktop-portal#236).
- Add pkgconfig(fontconfig) and pkgconfig(flatpak) BuildRequires:
  New dependencies.
- Add pkgconfig(libgeoclue-2.0) BuildRequires and pass
  enable-geoclue to configure, build new optional location portal.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Update to version 1.0.3:
  + Fix an option name in the remote desktop portal
  + document-portal: Validate permissions and report errors
  + Fix life-cycle issues with inodes in the document portal
  + Improve the test coverage of the documents portal
  + Add a 'coverage' make target
- Changes from version 1.0.2:
  + networkmonitor: Fix several issues
  + inhibit: Add session state monitoring
- Changes from version 1.0.1:
  + networkmonitor: Add GetStatus and CanReach methods
  + Unset GTK_USE_PORTAL
  + Add a portal for moving files to the trash
  + Fix an inode leak in the document portal
- Changes from version 1.0:
  + screenshot: Add a color picker api
  + screencast: Bump the pipewire dependency to 0.2.1
  + Improve --help output
  + Small documentation improvements
- Changes from version 0.99:
  + The NetworkMonitor portal API has been changed to allow access
    control
  + The Proxy and NetworkMonitor portals only respond to requests
    from sandboxes with network access
  + The flatpak portal is now documented
- Switch to tarball releases, upstream now releases stable
  tarballs.
- Following the above, drop libtool BuildRequires and autogen.sh
  macro call.
- Add pkgconfig(libpipewire-0.2) and pass --enable-pipewire to
  configure, build screencast and screenshot support.
* Tue Jun 26 2018 bjorn.lie@gmail.com
- Update to version 0.11:
  + OpenURI:
  - Fix misleading warning when accessing the permission store
  - Don't skip the dialog based on content type if a threshold is
    set
  + document-portal:
  - Support non-O_PATH fds for adding existing files
  - Only give DELETE right if you also get WRITE rights
  - Make fd validation stricter wrt /proc/pid/fd symlink
  - Rewrite paths in data
  - Verify access right on fds
  - Add some debug spew
  + XdpAppInfo: Nicer handling of kind
  + Add support for snap packages
  + XdpAppInfo: Centralize handling of xdp_app_info_new_host ()
  + Broaden what are valid app ids to allow snap.$PKGNAME
  + README: Fix docs link
  + Don't register http: uris
  + remote-desktop: Correct device type values
  + utils:
  - Generalize XdpAppInfo with a tagged union
  - Clarify content of app_infos hash table
  - Use more constants for interactions with the dbus-daemon
  - Don't leak names whose ownership changed
  + file-chooser: Handle save-file backend failure
  + screen-cast: add missing sync request
  + documents xml: Correct flag value for as-needed-by-app
  + build: Run install-test-data-hook as intended
  + Updated translations.
* Mon Mar  5 2018 fcrozat@suse.com
- Remove BuildRequires(flatpak), it is not needed.
- Own /usr/share/dbus-1, /usr/share/dbus-1/{interfaces,services}
  which were owned by flatpak package before.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Mon Feb 26 2018 dimstar@opensuse.org
- Update to version 0.10:
  + xdg-document-portal moved here from flatpak.
  + Add a new screencast and remote desktop portal based on
    PipeWire.
- Pass --disable-pipewire to configure: pipewire has not yet been
  packaged for openSUSE.
- Add pgkconfig(fuse) BuildRequires: new dependency.
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.9:
  + Install pkg-config files into datadir.
  + Avoid a race in the portal APIs.
  + Change the email portal to take fds.
  + Updated translations.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.8:
  + Update po files.
- Changes from version 0.7:
  + notification: Fix copy+paste error.
  + notification: Subscribe to the right interface for signals.
  + If the random request ID creates a collision, pick a new random
    ID.
  + Add some rationale.
  + Fix a typo.
  + Update README.md.
  + OpenURI: Refuse to handle file: uris.
  + Add an OpenFile method.
  + OpenFile: Fix URI.
  + Cache entire flatpak info file for peer, not just app id.
  + Store the cached flatpak-info keyfile with the request.
  + OpenFile: Rewrite app paths in /usr and /app (and /newroot).
  + OpenFile: Ensure that passed O_PATH fd is correct.
  + Send more data to the appchooser.
  + Updated translations.
- Changes from version 0.6:
  + Remove what appears to be printing lines from a debugging
    session.
  + open-uri: Fix segfault crash when no content-type can be
    resolved.
  + account: Remove debug spew.
  + Update README.md.
  + Add an email portal.
  + Include the email portal in the docs.
  + build: No need to clean org.freedesktop.portal.Desktop.service
    twice.
  + Add a systemd user unit corresponding to the session service.
  + notifications: Add better debug and error messages.
  + device: Add more detail to error messages.
  + Handle g_variant_lookup failure.
  + Encode po/Makevars in UTF-8.
  + Initialize autofree string variable to NULL.
  + open-uri: Implement a more permissive policy for the OpenURI
    portal.
  + data: Fix typo in NetworkMonitor XML definition.
  + Updated translations.
* Sun Jan 22 2017 zaitor@opensuse.org
- Update to version 0.5:
  + notification: Support 'non-exported actions.
  + Fix issues found in testing.
  + Avoid a crash when removing notifications.
  + Add an Account portal.
  + Change the Account portal API.
  + Update README.md.
  + Add a version property to all portal interfaces.
  + Fix a refcounting snafu.
  + file chooser:
  - Always grant write permissions for save dialogs.
  - Fix reading the writable property.
  + Simplify version support.
  + Updated translations.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 0.4:
  + No longer rely on cgroups to find the app id.
  + Fix handling of mime type filters in the file chooser portal.
  + Updated translations.
* Thu Nov  3 2016 dimstar@opensuse.org
- Initial package, version 0.3.
